resttools.Rest
==============

.. abjad-lineage:: abjad.tools.resttools.Rest.Rest.Rest

.. autoclass:: abjad.tools.resttools.Rest.Rest.Rest
   :noindex:

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.resttools.Rest.Rest.Rest.descendants
   :noindex:

.. autoattribute:: abjad.tools.resttools.Rest.Rest.Rest.duration_in_seconds
   :noindex:

.. autoattribute:: abjad.tools.resttools.Rest.Rest.Rest.leaf_index
   :noindex:

.. autoattribute:: abjad.tools.resttools.Rest.Rest.Rest.lilypond_format
   :noindex:

.. autoattribute:: abjad.tools.resttools.Rest.Rest.Rest.lineage
   :noindex:

.. autoattribute:: abjad.tools.resttools.Rest.Rest.Rest.multiplied_duration
   :noindex:

.. autoattribute:: abjad.tools.resttools.Rest.Rest.Rest.override
   :noindex:

.. autoattribute:: abjad.tools.resttools.Rest.Rest.Rest.parent
   :noindex:

.. autoattribute:: abjad.tools.resttools.Rest.Rest.Rest.parentage
   :noindex:

.. autoattribute:: abjad.tools.resttools.Rest.Rest.Rest.preprolated_duration
   :noindex:

.. autoattribute:: abjad.tools.resttools.Rest.Rest.Rest.prolated_duration
   :noindex:

.. autoattribute:: abjad.tools.resttools.Rest.Rest.Rest.prolation
   :noindex:

.. autoattribute:: abjad.tools.resttools.Rest.Rest.Rest.set
   :noindex:

.. autoattribute:: abjad.tools.resttools.Rest.Rest.Rest.spanners
   :noindex:

.. autoattribute:: abjad.tools.resttools.Rest.Rest.Rest.start_offset
   :noindex:

.. autoattribute:: abjad.tools.resttools.Rest.Rest.Rest.start_offset_in_seconds
   :noindex:

.. autoattribute:: abjad.tools.resttools.Rest.Rest.Rest.stop_offset
   :noindex:

.. autoattribute:: abjad.tools.resttools.Rest.Rest.Rest.stop_offset_in_seconds
   :noindex:

.. autoattribute:: abjad.tools.resttools.Rest.Rest.Rest.storage_format
   :noindex:

.. autoattribute:: abjad.tools.resttools.Rest.Rest.Rest.timespan
   :noindex:

.. autoattribute:: abjad.tools.resttools.Rest.Rest.Rest.timespan_in_seconds
   :noindex:

Read/write Properties
---------------------

.. autoattribute:: abjad.tools.resttools.Rest.Rest.Rest.duration_multiplier
   :noindex:

.. autoattribute:: abjad.tools.resttools.Rest.Rest.Rest.written_duration
   :noindex:

.. autoattribute:: abjad.tools.resttools.Rest.Rest.Rest.written_pitch_indication_is_at_sounding_pitch
   :noindex:

.. autoattribute:: abjad.tools.resttools.Rest.Rest.Rest.written_pitch_indication_is_nonsemantic
   :noindex:

Special Methods
---------------

.. automethod:: abjad.tools.resttools.Rest.Rest.Rest.__and__
   :noindex:

.. automethod:: abjad.tools.resttools.Rest.Rest.Rest.__eq__
   :noindex:

.. automethod:: abjad.tools.resttools.Rest.Rest.Rest.__ge__
   :noindex:

.. automethod:: abjad.tools.resttools.Rest.Rest.Rest.__gt__
   :noindex:

.. automethod:: abjad.tools.resttools.Rest.Rest.Rest.__le__
   :noindex:

.. automethod:: abjad.tools.resttools.Rest.Rest.Rest.__lt__
   :noindex:

.. automethod:: abjad.tools.resttools.Rest.Rest.Rest.__mul__
   :noindex:

.. automethod:: abjad.tools.resttools.Rest.Rest.Rest.__ne__
   :noindex:

.. automethod:: abjad.tools.resttools.Rest.Rest.Rest.__or__
   :noindex:

.. automethod:: abjad.tools.resttools.Rest.Rest.Rest.__repr__
   :noindex:

.. automethod:: abjad.tools.resttools.Rest.Rest.Rest.__rmul__
   :noindex:

.. automethod:: abjad.tools.resttools.Rest.Rest.Rest.__str__
   :noindex:

.. automethod:: abjad.tools.resttools.Rest.Rest.Rest.__sub__
   :noindex:

.. automethod:: abjad.tools.resttools.Rest.Rest.Rest.__xor__
   :noindex:
